#!/bin/bash

####################################################################################################

# Third-Party Tools / Installation Folders
PATH_TO_VIRALPRO="/home/.../VIRALpro_1.0"
PATH_TO_HMMER="/home/......./hmmer-3.1b2"
PATH_TO_R="/home/......./R-3.1.3"
PATH_TO_SCRATCH_1D="/home/......./SCRATCH-1D_1.1"

####################################################################################################

# Exporting Environment Variables
PATH=$PATH_TO_HMMER/bin:$PATH
LD_LIBRARY_PATH=$PATH_TO_HMMER/lib:$LD_LIBRARY_PATH
MANPATH=$PATH_TO_HMMER/share/man:$MANPATH
PATH=$PATH_TO_R/bin:$PATH
LD_LIBRARY_PATH=$PATH_TO_R/lib64:$LD_LIBRARY_PATH
MANPATH=$PATH_TO_R/share/man:$MANPATH
PATH=$PATH_TO_SCRATCH_1D/bin:$PATH
LD_LIBRARY_PATH=$PATH_TO_SCRATCH_1D/lib:$LD_LIBRARY_PATH
SCRATCH_RUN_SCRIPT="run_SCRATCH-1D_predictors.sh"

####################################################################################################

# Checking Script Arguments
[ "$#" -eq 2 ] || { echo "Usage $0 file.fasta ss/noSS"; exit 1; }
echo ""; echo "  VIRALpro 1.0... "; echo ""
if [[ $2 == ss ]] # Predict SS
then
  echo "  Using prediction of secondary structure as feature"
else
  echo "  No prediction of secondary structure will be processed."
fi
echo ""

####################################################################################################

# Scan HMMs
j=0
for i in $PATH_TO_VIRALPRO/HMM/cl*
do
  j=$(($j+1))
  hmmscan --max --tblout $1.hmmOut.tmp$j $i/globalHMM $1  > /dev/null
done
cat $1.hmmOut.tmp* | sed 's/_/\t/'  > $1.hmmOut
rm $1.hmmOut.tmp*

####################################################################################################

# Run SCRATCH-1D if Requested
if [[ $2 == ss ]] # Predict SS if required
  then
    $SCRATCH_RUN_SCRIPT $1 $1.out 4
    $PATH_TO_VIRALPRO/FASTAssBySequence.pl $1.out.ss > $1.ss
    $PATH_TO_VIRALPRO/FASTAaccBySequence.pl $1.out.acc > $1.acc
    rm $1.out.ss
    rm $1.out.acc
    rm $1.out.ss8
    rm $1.out.acc20
fi

####################################################################################################

# Extract sequence composition
$PATH_TO_VIRALPRO/FASTAcompositionBySequence.pl $1 > $1.composition

####################################################################################################

# Run the predictions
rdatadir="$PATH_TO_VIRALPRO"
runviralpro="$PATH_TO_VIRALPRO/runPrediction.R"
R --no-save --args $1 "capsids" $2 "$rdatadir" < $runviralpro > /dev/null 2> /dev/null
R --no-save --args $1 "tails" $2 "$rdatadir" < $runviralpro > /dev/null 2> /dev/null

####################################################################################################

# Clean
rm $1.composition
rm $1.hmmOut
if [[ $2 == ss ]] # Predict SS
  then
	rm $1.ss
	rm $1.acc
fi

####################################################################################################

